@@ -10,6 +10,16 @@ log = logger(__file__)
 
 app = Blueprint("geocoding", "geocoding")
 
+
+@app.route('/')
+@cross_origin(origins='*')
+def root():
+    """
+    Root REST service.
+    @return: Welcome message.
+    """
+    return 'Welcome to Geocoding Service!'
+
 @app.route('/discovery/')
 @app.route('/discovery')
 @cross_origin(origins='*')
@@ -21,13 +31,13 @@ def discovery():
     out = {
         'name': 'Geocoding service',
         'description': 'Geocoding service.',
-        'type': 'geocoding'
+        'type': 'SERVICE'
     }
     return Response(json.dumps(out), content_type='application/json; charset=utf-8')
 
 
-@app.route('/geocoding/latlon/<name>', methods=['GET'])
-@app.route('/geocoding/latlon/<name>', methods=['GET'])
+@app.route('/place/<name>', methods=['GET'])
+@app.route('/place/<name>', methods=['GET'])
 @cross_origin(origins='*')
 def find_geocoding(name):
     '''
@@ -38,6 +48,7 @@ def find_geocoding(name):
     print name
     names = name.split("|")
     result = get_locations(names)
+    print result
+    if result is None:
+        result = []
     return Response(json.dumps(result), content_type='application/json; charset=utf-8')
-
-
